==> haskell-vector-stream-0.1.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-stream
version:              0.1.0.1
visibility:           public
id:                   vector-stream-0.1.0.1-AnzbmjZCEugJDS2oIjCLpD
key:                  vector-stream-0.1.0.1-AnzbmjZCEugJDS2oIjCLpD
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012
    Alexey Kuleshevich 2020-2022,
    Aleksey Khudyakov 2020-2022,
    Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Streams
description:
    Simple yet powerful monadic streams that are used
    as a backbone for vector package fusion functionality.

category:             Data, Data Structures
abi:                  9165c04d40e8c4b409013382e23d4c3a
exposed:              True
exposed-modules:      Data.Stream.Monadic
import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-stream-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-stream-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-stream
hs-libraries:         HSvector-stream-0.1.0.1-AnzbmjZCEugJDS2oIjCLpD
depends:              base-4.16.4.0 ghc-prim-0.8.0
haddock-interfaces:
    /usr/share/doc/haskell-vector-stream/html/vector-stream.haddock

haddock-html:         /usr/share/doc/haskell-vector-stream/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-stream-0.1.0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-stream
version:              0.1.0.1
visibility:           public
id:                   vector-stream-0.1.0.1-F03bfhC0HhqL26lQDSs4vb
key:                  vector-stream-0.1.0.1-F03bfhC0HhqL26lQDSs4vb
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012
    Alexey Kuleshevich 2020-2022,
    Aleksey Khudyakov 2020-2022,
    Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Streams
description:
    Simple yet powerful monadic streams that are used
    as a backbone for vector package fusion functionality.

category:             Data, Data Structures
abi:                  2bf77f6066dcd4cfec934bfd4312efaf
exposed:              True
exposed-modules:      Data.Stream.Monadic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-stream-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-stream-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-stream-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-stream
hs-libraries:         HSvector-stream-0.1.0.1-F03bfhC0HhqL26lQDSs4vb
depends:              base-4.17.2.1 ghc-prim-0.9.1
haddock-interfaces:
    /usr/share/doc/haskell-vector-stream/html/vector-stream.haddock

haddock-html:         /usr/share/doc/haskell-vector-stream/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
